@@ -119,40 +119,40 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
 # Prepare data ------------------------------------------------------------
 
   # load plays with multiple laterals
-  mult_lats <- nflreadr::rds_from_url("https://github.com/nflverse/nflverse-data/releases/download/misc/multiple_lateral_yards.rds") %>%
+  mult_lats <- nflreadr::rds_from_url("https://github.com/nflverse/nflverse-data/releases/download/misc/multiple_lateral_yards.rds") |>
     dplyr::mutate(
-      season = substr(.data$game_id, 1, 4) %>% as.integer(),
-      week = substr(.data$game_id, 6, 7) %>% as.integer()
-    ) %>%
-    dplyr::filter(.data$yards != 0) %>%
+      season = substr(.data$game_id, 1, 4) |> as.integer(),
+      week = substr(.data$game_id, 6, 7) |> as.integer()
+    ) |>
+    dplyr::filter(.data$yards != 0) |>
     # the list includes all plays with multiple laterals
     # and all receivers. Since the last one already is in the
     # pbp data, we have to drop him here so the entry isn't duplicated
-    dplyr::group_by(.data$game_id, .data$play_id) %>%
-    dplyr::slice(seq_len(dplyr::n() - 1)) %>%
-    dplyr::ungroup() %>%
+    dplyr::group_by(.data$game_id, .data$play_id) |>
+    dplyr::slice(seq_len(dplyr::n() - 1)) |>
+    dplyr::ungroup() |>
     # there are some very rare cases where a player collects lateral yards
     # multiple times in the same play. We need to aggregate here to make sure
     # this don't messes up joins (#289)
-    dplyr::group_by(.data$season, .data$week, .data$type, .data$gsis_player_id) %>%
-    dplyr::summarise(yards = sum(.data$yards)) %>%
+    dplyr::group_by(.data$season, .data$week, .data$type, .data$gsis_player_id) |>
+    dplyr::summarise(yards = sum(.data$yards)) |>
     dplyr::ungroup()
 
   # filter down to the 2 dfs we need
   suppressMessages({
     # 1. for "normal" plays: get plays that count in official stats
-    data <- pbp %>%
+    data <- pbp |>
       dplyr::filter(
         !is.na(.data$down),
         .data$play_type %in% c("pass", "qb_kneel", "qb_spike", "run")
-      ) %>%
+      ) |>
       decode_player_ids()
 
     if (!"qb_epa" %in% names(data)) data <- add_qb_epa(data)
 
     # 2. for 2pt conversions only, get those plays
-    two_points <- pbp %>%
-      dplyr::filter(.data$two_point_conv_result == "success") %>%
+    two_points <- pbp |>
+      dplyr::filter(.data$two_point_conv_result == "success") |>
       dplyr::select(
         "week", "season", "posteam", "defteam",
         "pass_attempt", "rush_attempt",
@@ -161,12 +161,12 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
         "lateral_rusher_player_name", "lateral_rusher_player_id",
         "receiver_player_name", "receiver_player_id",
         "lateral_receiver_player_name", "lateral_receiver_player_id"
-      ) %>%
+      ) |>
       decode_player_ids()
   })
 
   if (!"special" %in% names(pbp)) {# we need this column for the special teams tds
-    pbp <- pbp %>%
+    pbp <- pbp |>
       dplyr::mutate(
         special = dplyr::if_else(
           .data$play_type %in% c("extra_point","field_goal","kickoff","punt"),
@@ -175,13 +175,13 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
       )
   }
 
-  s_type <- pbp %>%
-    dplyr::select("season", "season_type", "week") %>%
+  s_type <- pbp |>
+    dplyr::select("season", "season_type", "week") |>
     dplyr::distinct()
 
   # we'll join some player information like position or full name later
   # so we load it here to be able to use it for racr ids as well
-  player_info <- nflreadr::load_players() %>%
+  player_info <- nflreadr::load_players() |>
     dplyr::select(
       "player_id" = "gsis_id",
       "player_display_name" = "display_name",
@@ -192,16 +192,16 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
     )
 
   # load gsis_ids of RBs, FBs and HBs for RACR
-  racr_ids <- player_info %>%
-    dplyr::filter(.data$position %in% c("RB", "FB", "HB")) %>%
+  racr_ids <- player_info |>
+    dplyr::filter(.data$position %in% c("RB", "FB", "HB")) |>
     dplyr::select("gsis_id" = "player_id")
 
 # Passing stats -----------------------------------------------------------
 
   # get passing stats
-  pass_df <- data %>%
-    dplyr::filter(.data$play_type %in% c("pass", "qb_spike")) %>%
-    dplyr::group_by(.data$passer_player_id, .data$week, .data$season) %>%
+  pass_df <- data |>
+    dplyr::filter(.data$play_type %in% c("pass", "qb_spike")) |>
+    dplyr::group_by(.data$passer_player_id, .data$week, .data$season) |>
     dplyr::summarize(
       passing_yards_after_catch = sum((.data$passing_yards - .data$air_yards) * .data$complete_pass, na.rm = TRUE),
       name_pass = dplyr::first(.data$passer_player_name),
@@ -225,30 +225,30 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
         .data$passing_air_yards <= 0 ~ 0,
         TRUE ~ .data$pacr
       ),
-    ) %>%
-    dplyr::rename("player_id" = "passer_player_id") %>%
+    ) |>
+    dplyr::rename("player_id" = "passer_player_id") |>
     dplyr::ungroup()
 
   if (isTRUE(weekly)) pass_df <- add_dakota(pass_df, pbp = pbp, weekly = weekly)
 
-  pass_two_points <- two_points %>%
-    dplyr::filter(.data$pass_attempt == 1) %>%
-    dplyr::group_by(.data$passer_player_id, .data$week, .data$season) %>%
+  pass_two_points <- two_points |>
+    dplyr::filter(.data$pass_attempt == 1) |>
+    dplyr::group_by(.data$passer_player_id, .data$week, .data$season) |>
     dplyr::summarise(
       # need name_pass and team_pass here for the full join in the next pipe
       name_pass = custom_mode(.data$passer_player_name),
       team_pass = custom_mode(.data$posteam),
       opp_pass = custom_mode(.data$defteam),
       passing_2pt_conversions = dplyr::n()
-    ) %>%
-    dplyr::rename("player_id" = "passer_player_id") %>%
+    ) |>
+    dplyr::rename("player_id" = "passer_player_id") |>
     dplyr::ungroup()
 
-  pass_df <- pass_df %>%
+  pass_df <- pass_df |>
     # need a full join because players without passing stats that recorded
     # a passing two point (e.g. WRs) are dropped in any other join
-    dplyr::full_join(pass_two_points, by = c("player_id", "week", "season", "name_pass", "team_pass", "opp_pass")) %>%
-    dplyr::mutate(passing_2pt_conversions = dplyr::if_else(is.na(.data$passing_2pt_conversions), 0L, .data$passing_2pt_conversions)) %>%
+    dplyr::full_join(pass_two_points, by = c("player_id", "week", "season", "name_pass", "team_pass", "opp_pass")) |>
+    dplyr::mutate(passing_2pt_conversions = dplyr::if_else(is.na(.data$passing_2pt_conversions), 0L, .data$passing_2pt_conversions)) |>
     dplyr::filter(!is.na(.data$player_id))
 
   pass_df_nas <- is.na(pass_df)
@@ -260,9 +260,9 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
 # Rushing stats -----------------------------------------------------------
 
   # rush df 1: primary rusher
-  rushes <- data %>%
-    dplyr::filter(.data$play_type %in% c("run", "qb_kneel")) %>%
-    dplyr::group_by(.data$rusher_player_id, .data$week, .data$season) %>%
+  rushes <- data |>
+    dplyr::filter(.data$play_type %in% c("run", "qb_kneel")) |>
+    dplyr::group_by(.data$rusher_player_id, .data$week, .data$season) |>
     dplyr::summarize(
       name_rush = dplyr::first(.data$rusher_player_name),
       team_rush = dplyr::first(.data$posteam),
@@ -274,13 +274,13 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
       rushing_fumbles_lost = sum(.data$fumble_lost == 1 & .data$fumbled_1_player_id == .data$rusher_player_id & is.na(.data$lateral_rusher_player_id) & .data$fumble_recovery_1_team != .data$posteam),
       rushing_first_downs = sum(.data$first_down_rush & is.na(.data$lateral_rusher_player_id)),
       rushing_epa = sum(.data$epa, na.rm = TRUE)
-    ) %>%
+    ) |>
     dplyr::ungroup()
 
   # rush df 2: lateral
-  laterals <- data %>%
-    dplyr::filter(!is.na(.data$lateral_rusher_player_id)) %>%
-    dplyr::group_by(.data$lateral_rusher_player_id, .data$week, .data$season) %>%
+  laterals <- data |>
+    dplyr::filter(!is.na(.data$lateral_rusher_player_id)) |>
+    dplyr::group_by(.data$lateral_rusher_player_id, .data$week, .data$season) |>
     dplyr::summarize(
       lateral_yards = sum(.data$lateral_rushing_yards, na.rm = TRUE),
       lateral_fds = sum(.data$first_down_rush, na.rm = TRUE),
@@ -288,68 +288,68 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
       lateral_att = dplyr::n(),
       lateral_fumbles =  sum(.data$fumble, na.rm = TRUE),
       lateral_fumbles_lost = sum(.data$fumble_lost, na.rm = TRUE)
-    ) %>%
-    dplyr::ungroup() %>%
-    dplyr::rename("rusher_player_id" = "lateral_rusher_player_id") %>%
+    ) |>
+    dplyr::ungroup() |>
+    dplyr::rename("rusher_player_id" = "lateral_rusher_player_id") |>
     dplyr::bind_rows(
-      mult_lats %>%
+      mult_lats |>
         dplyr::filter(
           .data$type == "lateral_rushing" & .data$season %in% data$season & .data$week %in% data$week
-        ) %>%
-        dplyr::select("season", "week", "rusher_player_id" = "gsis_player_id", "lateral_yards" = "yards") %>%
+        ) |>
+        dplyr::select("season", "week", "rusher_player_id" = "gsis_player_id", "lateral_yards" = "yards") |>
         dplyr::mutate(lateral_tds = 0L, lateral_att = 1L)
-    ) %>%
+    ) |>
     # at this stage it is possible that a player is duplicated because he
     # has lateral yards both in the regular pbp and in the multiple laterals file.
     # This can happen when a player was the last lateral player in one play and
     # not the last lateral player in another play in the same game (wow absurd)
     # We summarise all columns to make sure there is only one row per player
     # per game. See (#289)
-    dplyr::group_by(.data$rusher_player_id, .data$week, .data$season) %>%
-    dplyr::summarise_all(.funs = sum, na.rm = TRUE) %>%
+    dplyr::group_by(.data$rusher_player_id, .data$week, .data$season) |>
+    dplyr::summarise_all(.funs = sum, na.rm = TRUE) |>
     dplyr::ungroup()
 
   # rush df: join
-  rush_df <- rushes %>%
-    dplyr::left_join(laterals, by = c("rusher_player_id", "week", "season")) %>%
+  rush_df <- rushes |>
+    dplyr::left_join(laterals, by = c("rusher_player_id", "week", "season")) |>
     dplyr::mutate(
       lateral_yards = dplyr::if_else(is.na(.data$lateral_yards), 0, .data$lateral_yards),
       lateral_tds = dplyr::if_else(is.na(.data$lateral_tds), 0L, .data$lateral_tds),
       lateral_fumbles = dplyr::if_else(is.na(.data$lateral_fumbles), 0, .data$lateral_fumbles),
       lateral_fumbles_lost = dplyr::if_else(is.na(.data$lateral_fumbles_lost), 0, .data$lateral_fumbles_lost),
       lateral_fds = dplyr::if_else(is.na(.data$lateral_fds), 0, .data$lateral_fds)
-    ) %>%
+    ) |>
     dplyr::mutate(
       rushing_yards = .data$yards + .data$lateral_yards,
       rushing_tds = .data$tds + .data$lateral_tds,
       rushing_first_downs = .data$rushing_first_downs + .data$lateral_fds,
       rushing_fumbles = .data$rushing_fumbles + .data$lateral_fumbles,
       rushing_fumbles_lost = .data$rushing_fumbles_lost + .data$lateral_fumbles_lost
-      ) %>%
-    dplyr::rename("player_id" = "rusher_player_id") %>%
+      ) |>
+    dplyr::rename("player_id" = "rusher_player_id") |>
     dplyr::select("player_id", "week", "season", "name_rush", "team_rush", "opp_rush",
                   "rushing_yards", "carries", "rushing_tds", "rushing_fumbles",
-                  "rushing_fumbles_lost", "rushing_first_downs", "rushing_epa") %>%
+                  "rushing_fumbles_lost", "rushing_first_downs", "rushing_epa") |>
     dplyr::ungroup()
 
-  rush_two_points <- two_points %>%
-    dplyr::filter(.data$rush_attempt == 1) %>%
-    dplyr::group_by(.data$rusher_player_id, .data$week, .data$season) %>%
+  rush_two_points <- two_points |>
+    dplyr::filter(.data$rush_attempt == 1) |>
+    dplyr::group_by(.data$rusher_player_id, .data$week, .data$season) |>
     dplyr::summarise(
       # need name_rush and team_rush here for the full join in the next pipe
       name_rush = custom_mode(.data$rusher_player_name),
       team_rush = custom_mode(.data$posteam),
       opp_rush = custom_mode(.data$defteam),
       rushing_2pt_conversions = dplyr::n()
-    ) %>%
-    dplyr::rename("player_id" = "rusher_player_id") %>%
+    ) |>
+    dplyr::rename("player_id" = "rusher_player_id") |>
     dplyr::ungroup()
 
-  rush_df <- rush_df %>%
+  rush_df <- rush_df |>
     # need a full join because players without rushing stats that recorded
     # a rushing two point (mostly QBs) are dropped in any other join
-    dplyr::full_join(rush_two_points, by = c("player_id", "week", "season", "name_rush", "team_rush", "opp_rush")) %>%
-    dplyr::mutate(rushing_2pt_conversions = dplyr::if_else(is.na(.data$rushing_2pt_conversions), 0L, .data$rushing_2pt_conversions)) %>%
+    dplyr::full_join(rush_two_points, by = c("player_id", "week", "season", "name_rush", "team_rush", "opp_rush")) |>
+    dplyr::mutate(rushing_2pt_conversions = dplyr::if_else(is.na(.data$rushing_2pt_conversions), 0L, .data$rushing_2pt_conversions)) |>
     dplyr::filter(!is.na(.data$player_id))
 
   rush_df_nas <- is.na(rush_df)
@@ -361,9 +361,9 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
 # Receiving stats ---------------------------------------------------------
 
   # receiver df 1: primary receiver
-  rec <- data %>%
-    dplyr::filter(!is.na(.data$receiver_player_id)) %>%
-    dplyr::group_by(.data$receiver_player_id, .data$week, .data$season) %>%
+  rec <- data |>
+    dplyr::filter(!is.na(.data$receiver_player_id)) |>
+    dplyr::group_by(.data$receiver_player_id, .data$week, .data$season) |>
     dplyr::summarize(
       name_receiver = dplyr::first(.data$receiver_player_name),
       team_receiver = dplyr::first(.data$posteam),
@@ -378,13 +378,13 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
       receiving_yards_after_catch = sum(.data$yards_after_catch, na.rm = TRUE),
       receiving_first_downs = sum(.data$first_down_pass & is.na(.data$lateral_receiver_player_id)),
       receiving_epa = sum(.data$epa, na.rm = TRUE)
-    ) %>%
+    ) |>
     dplyr::ungroup()
 
   # receiver df 2: lateral
-  laterals <- data %>%
-    dplyr::filter(!is.na(.data$lateral_receiver_player_id)) %>%
-    dplyr::group_by(.data$lateral_receiver_player_id, .data$week, .data$season) %>%
+  laterals <- data |>
+    dplyr::filter(!is.na(.data$lateral_receiver_player_id)) |>
+    dplyr::group_by(.data$lateral_receiver_player_id, .data$week, .data$season) |>
     dplyr::summarize(
       lateral_yards = sum(.data$lateral_receiving_yards, na.rm = TRUE),
       lateral_tds = sum(.data$td_player_id == .data$lateral_receiver_player_id, na.rm = TRUE),
@@ -392,48 +392,48 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
       lateral_fds = sum(.data$first_down_pass, na.rm = T),
       lateral_fumbles = sum(.data$fumble, na.rm = T),
       lateral_fumbles_lost = sum(.data$fumble_lost, na.rm = T)
-    ) %>%
-    dplyr::ungroup() %>%
-    dplyr::rename("receiver_player_id" = "lateral_receiver_player_id") %>%
+    ) |>
+    dplyr::ungroup() |>
+    dplyr::rename("receiver_player_id" = "lateral_receiver_player_id") |>
     dplyr::bind_rows(
-      mult_lats %>%
+      mult_lats |>
         dplyr::filter(
           .data$type == "lateral_receiving" & .data$season %in% data$season & .data$week %in% data$week
-        ) %>%
-        dplyr::select("season", "week", "receiver_player_id" = "gsis_player_id", "lateral_yards" = "yards") %>%
+        ) |>
+        dplyr::select("season", "week", "receiver_player_id" = "gsis_player_id", "lateral_yards" = "yards") |>
         dplyr::mutate(lateral_tds = 0L, lateral_att = 1L)
-    ) %>%
+    ) |>
     # at this stage it is possible that a player is duplicated because he
     # has lateral yards both in the regular pbp and in the multiple laterals file.
     # This can happen when a player was the last lateral player in one play and
     # not the last lateral player in another play in the same game (wow absurd)
     # We summarise all columns to get make sure there is only one row per player
     # per game. See (#289)
-    dplyr::group_by(.data$receiver_player_id, .data$week, .data$season) %>%
-    dplyr::summarise_all(.funs = sum, na.rm = TRUE) %>%
+    dplyr::group_by(.data$receiver_player_id, .data$week, .data$season) |>
+    dplyr::summarise_all(.funs = sum, na.rm = TRUE) |>
     dplyr::ungroup()
 
   # receiver df 3: team receiving for WOPR
-  rec_team <- data %>%
-    dplyr::filter(!is.na(.data$receiver_player_id)) %>%
-    dplyr::group_by(.data$posteam, .data$week, .data$season) %>%
+  rec_team <- data |>
+    dplyr::filter(!is.na(.data$receiver_player_id)) |>
+    dplyr::group_by(.data$posteam, .data$week, .data$season) |>
     dplyr::summarize(
       team_targets = dplyr::n(),
       team_air_yards = sum(.data$air_yards, na.rm = TRUE),
-    ) %>%
+    ) |>
     dplyr::ungroup()
 
   # rec df: join
-  rec_df <- rec %>%
-    dplyr::left_join(laterals, by = c("receiver_player_id", "week", "season")) %>%
-    dplyr::left_join(rec_team, by = c("team_receiver" = "posteam", "week", "season")) %>%
+  rec_df <- rec |>
+    dplyr::left_join(laterals, by = c("receiver_player_id", "week", "season")) |>
+    dplyr::left_join(rec_team, by = c("team_receiver" = "posteam", "week", "season")) |>
     dplyr::mutate(
       lateral_yards = dplyr::if_else(is.na(.data$lateral_yards), 0, .data$lateral_yards),
       lateral_tds = dplyr::if_else(is.na(.data$lateral_tds), 0L, .data$lateral_tds),
       lateral_fumbles = dplyr::if_else(is.na(.data$lateral_fumbles), 0, .data$lateral_fumbles),
       lateral_fumbles_lost = dplyr::if_else(is.na(.data$lateral_fumbles_lost), 0, .data$lateral_fumbles_lost),
       lateral_fds = dplyr::if_else(is.na(.data$lateral_fds), 0, .data$lateral_fds)
-    ) %>%
+    ) |>
     dplyr::mutate(
       receiving_yards = .data$yards + .data$lateral_yards,
       receiving_tds = .data$tds + .data$lateral_tds,
@@ -453,32 +453,32 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
       target_share = .data$targets / .data$team_targets,
       air_yards_share = .data$receiving_air_yards / .data$team_air_yards,
       wopr = 1.5 * .data$target_share + 0.7 * .data$air_yards_share
-      ) %>%
-    dplyr::rename("player_id" = "receiver_player_id") %>%
+      ) |>
+    dplyr::rename("player_id" = "receiver_player_id") |>
     dplyr::select("player_id", "week", "season", "name_receiver", "team_receiver", "opp_receiver",
                   "receiving_yards", "receiving_air_yards", "receiving_yards_after_catch",
                   "receptions", "targets", "receiving_tds", "receiving_fumbles",
                   "receiving_fumbles_lost", "receiving_first_downs", "receiving_epa",
                   "racr", "target_share", "air_yards_share", "wopr")
 
-  rec_two_points <- two_points %>%
-    dplyr::filter(.data$pass_attempt == 1) %>%
-    dplyr::group_by(.data$receiver_player_id, .data$week, .data$season) %>%
+  rec_two_points <- two_points |>
+    dplyr::filter(.data$pass_attempt == 1) |>
+    dplyr::group_by(.data$receiver_player_id, .data$week, .data$season) |>
     dplyr::summarise(
       # need name_receiver and team_receiver here for the full join in the next pipe
       name_receiver = custom_mode(.data$receiver_player_name),
       team_receiver = custom_mode(.data$posteam),
       opp_receiver = custom_mode(.data$defteam),
       receiving_2pt_conversions = dplyr::n()
-    ) %>%
-    dplyr::rename("player_id" = "receiver_player_id") %>%
+    ) |>
+    dplyr::rename("player_id" = "receiver_player_id") |>
     dplyr::ungroup()
 
-  rec_df <- rec_df %>%
+  rec_df <- rec_df |>
     # need a full join because players without receiving stats that recorded
     # a receiving two point are dropped in any other join
-    dplyr::full_join(rec_two_points, by = c("player_id", "week", "season", "name_receiver", "team_receiver", "opp_receiver")) %>%
-    dplyr::mutate(receiving_2pt_conversions = dplyr::if_else(is.na(.data$receiving_2pt_conversions), 0L, .data$receiving_2pt_conversions)) %>%
+    dplyr::full_join(rec_two_points, by = c("player_id", "week", "season", "name_receiver", "team_receiver", "opp_receiver")) |>
+    dplyr::mutate(receiving_2pt_conversions = dplyr::if_else(is.na(.data$receiving_2pt_conversions), 0L, .data$receiving_2pt_conversions)) |>
     dplyr::filter(!is.na(.data$player_id), !is.na(.data$name_receiver))
 
   rec_df_nas <- is.na(rec_df)
@@ -490,25 +490,25 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
 
 # Special Teams -----------------------------------------------------------
 
-  st_tds <- pbp %>%
-    dplyr::filter(.data$special == 1 & !is.na(.data$td_player_id)) %>%
-    dplyr::group_by(.data$td_player_id, .data$week, .data$season) %>%
+  st_tds <- pbp |>
+    dplyr::filter(.data$special == 1 & !is.na(.data$td_player_id)) |>
+    dplyr::group_by(.data$td_player_id, .data$week, .data$season) |>
     dplyr::summarise(
       name_st = custom_mode(.data$td_player_name),
       team_st = custom_mode(.data$td_team),
       opp_st = custom_mode(.data$defteam),
       special_teams_tds = sum(.data$touchdown, na.rm = TRUE)
-    ) %>%
+    ) |>
     dplyr::rename("player_id" = "td_player_id")
 
 # Combine all stats -------------------------------------------------------
 
   # combine all the stats together
-  player_df <- pass_df %>%
-    dplyr::full_join(rush_df, by = c("player_id", "week", "season")) %>%
-    dplyr::full_join(rec_df, by = c("player_id", "week", "season")) %>%
-    dplyr::full_join(st_tds, by = c("player_id", "week", "season")) %>%
-    dplyr::left_join(s_type, by = c("season", "week")) %>%
+  player_df <- pass_df |>
+    dplyr::full_join(rush_df, by = c("player_id", "week", "season")) |>
+    dplyr::full_join(rec_df, by = c("player_id", "week", "season")) |>
+    dplyr::full_join(st_tds, by = c("player_id", "week", "season")) |>
+    dplyr::left_join(s_type, by = c("season", "week")) |>
     dplyr::mutate(
       player_name = dplyr::case_when(
         !is.na(.data$name_pass) ~ .data$name_pass,
@@ -528,8 +528,8 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
         !is.na(.data$opp_receiver) ~ .data$opp_receiver,
         TRUE ~ .data$opp_st
       )
-    ) %>%
-    dplyr::select(tidyselect::any_of(c(
+    ) |>
+    dplyr::select(dplyr::any_of(c(
 
       # id information
       "player_id", "player_name", "recent_team", "season", "week", "season_type", "opponent_team",
@@ -552,7 +552,7 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
       # special teams
       "special_teams_tds"
 
-    ))) %>%
+    ))) |>
     dplyr::filter(!is.na(.data$player_id), !is.na(.data$player_name))
 
   player_df_nas <- is.na(player_df)
@@ -561,7 +561,7 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
 
   player_df[player_df_nas] <- 0
 
-  player_df <- player_df %>%
+  player_df <- player_df |>
     dplyr::mutate(
       fantasy_points =
         1 / 25 * .data$passing_yards +
@@ -573,20 +573,20 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
         -2 * (.data$sack_fumbles_lost + .data$rushing_fumbles_lost + .data$receiving_fumbles_lost),
 
       fantasy_points_ppr = .data$fantasy_points + .data$receptions
-    ) %>%
+    ) |>
     dplyr::arrange(.data$player_id, .data$season, .data$week)
 
 
   # if user doesn't want week-by-week input, aggregate the whole df
   if (isFALSE(weekly)) {
-    player_df <- player_df %>%
+    player_df <- player_df |>
       # helper variables to summarise targetshare and air yard share
       # because targets and air yards summarise first
       dplyr::mutate(
         tgts = .data$targets,
         rec_air_yds = .data$receiving_air_yards
-      ) %>%
-      dplyr::group_by(.data$player_id) %>%
+      ) |>
+      dplyr::group_by(.data$player_id) |>
       dplyr::summarise(
         player_name = custom_mode(.data$player_name),
         games = dplyr::n(),
@@ -641,8 +641,8 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
         # fantasy
         fantasy_points = sum(.data$fantasy_points),
         fantasy_points_ppr = sum(.data$fantasy_points_ppr)
-      ) %>%
-      dplyr::ungroup() %>%
+      ) |>
+      dplyr::ungroup() |>
       dplyr::mutate(
         racr = dplyr::case_when(
           is.nan(.data$racr) ~ NA_real_,
@@ -657,20 +657,20 @@ calculate_player_stats <- function(pbp, weekly = FALSE) {
           .data$passing_air_yards <= 0 ~ 0,
           TRUE ~ .data$pacr
         )
-      ) %>%
-      add_dakota(pbp = pbp, weekly = weekly) %>%
+      ) |>
+      add_dakota(pbp = pbp, weekly = weekly) |>
       dplyr::select(
         "player_id":"pacr",
-        tidyselect::any_of("dakota"),
+        dplyr::any_of("dakota"),
         dplyr::everything()
       )
   }
 
   # data is missing position and player name can be messed up in pbp
   # so we join player information next
-  player_df <- player_df %>%
-    dplyr::select(-"player_name") %>%
-    dplyr::left_join(player_info, by = "player_id") %>%
+  player_df <- player_df |>
+    dplyr::select(-"player_name") |>
+    dplyr::left_join(player_info, by = "player_id") |>
     dplyr::select(
       "player_id",
       "player_name",
@@ -699,62 +699,62 @@ add_dakota <- function(add_to_this, pbp, weekly) {
   if (!"qb_epa" %in% names(pbp)) pbp <- add_qb_epa(pbp)
 
   suppressMessages({
-    df <- pbp %>%
-      dplyr::filter(.data$pass == 1 | .data$rush == 1) %>%
-      dplyr::filter(!is.na(.data$posteam) & !is.na(.data$qb_epa) & !is.na(.data$id) & !is.na(.data$down)) %>%
-      dplyr::mutate(epa = dplyr::if_else(.data$qb_epa < -4.5, -4.5, .data$qb_epa)) %>%
+    df <- pbp |>
+      dplyr::filter(.data$pass == 1 | .data$rush == 1) |>
+      dplyr::filter(!is.na(.data$posteam) & !is.na(.data$qb_epa) & !is.na(.data$id) & !is.na(.data$down)) |>
+      dplyr::mutate(epa = dplyr::if_else(.data$qb_epa < -4.5, -4.5, .data$qb_epa)) |>
       decode_player_ids()
   })
 
   if (isTRUE(weekly)) {
-    relevant_players <- add_to_this %>%
-      dplyr::filter(.data$attempts >= 5) %>%
-      dplyr::mutate(filter_id = paste(.data$player_id, .data$season, .data$week, sep = "_")) %>%
+    relevant_players <- add_to_this |>
+      dplyr::filter(.data$attempts >= 5) |>
+      dplyr::mutate(filter_id = paste(.data$player_id, .data$season, .data$week, sep = "_")) |>
       dplyr::pull(.data$filter_id)
 
-    model_data <- df %>%
-      dplyr::group_by(.data$id, .data$week, .data$season) %>%
+    model_data <- df |>
+      dplyr::group_by(.data$id, .data$week, .data$season) |>
       dplyr::summarize(
         n_plays = n(),
         epa_per_play = sum(.data$epa) / .data$n_plays,
         cpoe = mean(.data$cpoe, na.rm = TRUE)
-      ) %>%
-      dplyr::ungroup() %>%
-      dplyr::mutate(cpoe = dplyr::if_else(is.na(.data$cpoe), 0, .data$cpoe)) %>%
-      dplyr::rename("player_id" = "id") %>%
-      dplyr::mutate(filter_id = paste(.data$player_id, .data$season, .data$week, sep = "_")) %>%
+      ) |>
+      dplyr::ungroup() |>
+      dplyr::mutate(cpoe = dplyr::if_else(is.na(.data$cpoe), 0, .data$cpoe)) |>
+      dplyr::rename("player_id" = "id") |>
+      dplyr::mutate(filter_id = paste(.data$player_id, .data$season, .data$week, sep = "_")) |>
       dplyr::filter(.data$filter_id %in% relevant_players)
 
-    model_data$dakota <- mgcv::predict.gam(dakota_model, model_data) %>% as.vector()
+    model_data$dakota <- mgcv::predict.gam(dakota_model, model_data) |> as.vector()
 
-    out <- add_to_this %>%
+    out <- add_to_this |>
       dplyr::left_join(
-        model_data %>%
+        model_data |>
           dplyr::select("player_id", "week", "season", "dakota"),
         by = c("player_id", "week", "season")
       )
   } else if (isFALSE(weekly)) {
-    relevant_players <- add_to_this %>%
-      dplyr::filter(.data$attempts >= 5) %>%
+    relevant_players <- add_to_this |>
+      dplyr::filter(.data$attempts >= 5) |>
       dplyr::pull(.data$player_id)
 
-    model_data <- df %>%
-      dplyr::group_by(.data$id) %>%
+    model_data <- df |>
+      dplyr::group_by(.data$id) |>
       dplyr::summarize(
         n_plays = n(),
         epa_per_play = sum(.data$epa) / .data$n_plays,
         cpoe = mean(.data$cpoe, na.rm = TRUE)
-      ) %>%
-      dplyr::ungroup() %>%
-      dplyr::mutate(cpoe = dplyr::if_else(is.na(.data$cpoe), 0, .data$cpoe)) %>%
-      dplyr::rename("player_id" = "id") %>%
+      ) |>
+      dplyr::ungroup() |>
+      dplyr::mutate(cpoe = dplyr::if_else(is.na(.data$cpoe), 0, .data$cpoe)) |>
+      dplyr::rename("player_id" = "id") |>
       dplyr::filter(.data$player_id %in% relevant_players)
 
-    model_data$dakota <- mgcv::predict.gam(dakota_model, model_data) %>% as.vector()
+    model_data$dakota <- mgcv::predict.gam(dakota_model, model_data) |> as.vector()
 
-    out <- add_to_this %>%
+    out <- add_to_this |>
       dplyr::left_join(
-        model_data %>%
+        model_data |>
           dplyr::select("player_id", "dakota"),
         by = "player_id"
       )
